Module async_adapter

Module async_adapter 

Structs

AsyncFd
Runtime-owned readiness source passed to an AsyncFdAdapter.
AsyncFdRef
Borrowed readiness source returned by an AsyncFdReadyGuard.

Traits

AsyncFdAdapter
A runtime adapter that can register an existing nonblocking file descriptor for async waiting.
AsyncFdReadyGuard
Guard returned once the runtime reports the watch file descriptor as readable.
AsyncFdRegistration
Registered readiness source for a watch file descriptor.

Type Aliases

AsyncFdReadableFuture