Structs
- AsyncFd
- Runtime-owned readiness source passed to an
AsyncFdAdapter. - Async
FdRef - Borrowed readiness source returned by an
AsyncFdReadyGuard.
Traits
- Async
FdAdapter - A runtime adapter that can register an existing nonblocking file descriptor for async waiting.
- Async
FdReady Guard - Guard returned once the runtime reports the watch file descriptor as readable.
- Async
FdRegistration - Registered readiness source for a watch file descriptor.